@@ -24,10 +24,7 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
-#ifdef WIN32
 #include "win32.h"
-#endif
-
 #include "comp_fail.h"
 
 #ifndef DACT_CONTACT
@@ -40,8 +37,8 @@
 
 #define DACT_VER_MAJOR 0
 #define DACT_VER_MINOR 8
-#define DACT_VER_REVISION 36
-#define DACT_VERSION "0.8.36"
+#define DACT_VER_REVISION 37
+#define DACT_VERSION "0.8.37"
 #ifdef DEBUG
 #define DACT_VER_SUB	"dev"
 #else
@@ -93,8 +90,8 @@
 
 #ifndef DACT_BLK_SIZE_MAX
 #define DACT_BLK_SIZE_MAX 2147483647
-#define MAX_DACT_BLK_SIZE DACT_BLK_SIZE_MAX
 #endif
+
 #ifndef DACT_BLK_SIZE_DEF
 #define DACT_BLK_SIZE_DEF 8192
 #endif
@@ -108,6 +105,15 @@
 #ifndef HAVE_STRSEP
 #include "strsep.h"
 #endif
+#ifndef HAVE_GETPASS
+#include "getpass.h"
+#endif
+#ifndef HAVE_MKSTEMP
+#include "mkstemp.h"
+#endif
+#ifndef HAVE_UNAME
+#include "uname.h"
+#endif
 
 #ifdef HAVE_STDINT_H
 #include <stdint.h>
@@ -118,6 +124,13 @@
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
+#ifdef HAVE_STDIO_H
+#include <stdio.h>
+#endif
+#ifdef HAVE_ERRNO_H
+#include <errno.h>
+#endif
+
 
 #define DACT_MAGIC_NUMBER 0x444354C3
 #define DACT_MAGIC_OFFSET 0
@@ -126,13 +139,11 @@
 
 #define DACT_HDR_REG_SIZE 24
 
-struct dact_header {
-	uint32_t	size;
-	unsigned char	algo;
-};
-
-extern uint32_t DACT_BLK_SIZE;
 extern char dact_nonetwork;
+struct dact_header {
+	uint32_t size;
+	unsigned char algo;
+};
 
 #if defined(__FILE__) && defined(__LINE__) && defined(DEBUG)
 #define PRINT_LINE fprintf(stderr, "%s:%07i:%s(): ", __FILE__, __LINE__, __func__)
@@ -140,12 +151,10 @@ extern char dact_nonetwork;
 #define PRINT_LINE /**/
 #endif
 
-#define PERROR(error) { PRINT_LINE; perror("dact: " error); }
-#define PERROR_L(errnum, error) { PRINT_LINE; fprintf(stderr, "%s: %s\n", error, strerror(abs(errnum))); }
+#define PERROR_L(errnum, error) { PRINT_LINE; fprintf(stderr, "dact: %s: %s\n", error, strerror(abs(errnum))); }
 #define PRINTERR(error) { PRINT_LINE; fprintf(stderr, "dact: " error "\n"); }
-
-/* Win32 check here */
-
+#define PERROR(error) PERROR_L(errno, error)
+/* #define PERROR(error) { PRINT_LINE; perror("dact: " error); } */
 
 #ifdef DEBUG
 #define SPOTVAR_NUM(x) { PRINT_LINE; fprintf(stderr, "dact: %s=%li\n", #x, (long) x); }
@@ -161,10 +170,6 @@ extern char dact_nonetwork;
 #define DACT_FAILED_ALGO comp_fail_algo
 #endif
 
-#ifndef HAVE_SYS_SOCKET_H
-#define NO_NETWORK 1
-#endif
-
 #ifdef HAVE_DEV_URANDOM
 #define RANDOM_DEV "/dev/urandom"
 #endif
@@ -183,25 +188,29 @@ extern char dact_nonetwork;
 #define DACT_BIN_DIR "@@HOME@@/.dact/@@OSNM@@-@@ARCH@@/"
 #endif
 #ifndef DACT_BIN
+#ifdef EXEEXT
+#define DACT_BIN DACT_BIN_DIR "dact" EXEEXT
+#else
 #define DACT_BIN DACT_BIN_DIR "dact.bin"
 #endif
+#endif
 #define DACT_BIN_VER ((DACT_VER_MAJOR<<16)|(DACT_VER_MINOR<<8)|DACT_VER_REVISION)
 
-
+/* We need to determine when we have network support */
+#if !defined(HAVE_SOCKET) || !defined(HAVE_GETHOSTBYNAME) || (!defined(HAVE_INET_ATON) && !defined(HAVE_INET_ADDR))
+#ifndef NO_NETWORK
+#define NO_NETWORK 1
+#endif
+#endif
 
 
 int print_help(int argc, char **argv);
 int dact_blksize_calc(int fsize);
-void dact_config_loadfile(const char *path, char *options);
-int dact_config_execute(const char *cmd, char *options);
 int dact_upgrade_file_checkver(const char *name, const char *url_ver, const char *options);
 int dact_upgrade_file(const char *name, const char *url_get, const char *url_ver, uint32_t version, const char *dest, const char *options);
 int dact_shutdown(int retval);
 char *dact_getoutfilename(const char *orig, const int mode);
 uint32_t dact_process_other(int src, const int dest, const uint32_t magic, const char *options);
-uint32_t dact_blk_decompress(char *ret, const char *srcbuf, const uint32_t size, const char *options, const int algo);
-uint32_t dact_blk_compress(char *algo, char *ret, const char *srcbuf, const uint32_t size, const char *options);
-uint32_t dact_process_file(const int src, const int dest, const int mode, const char *options, const char *filename, uint32_t *crcs, int cipher);
 int main(int argc, char **argv);
 
 #endif/*_DACT_H*/
