@@ -23,7 +23,9 @@
 */
 
 #include "dact.h"
+#ifdef HAVE_SYS_UTSNAME_H
 #include <sys/utsname.h>
+#endif
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
@@ -418,8 +420,8 @@ char *demime64(unsigned char *str) {
 }
 
 
-ssize_t read_f(int fd, void *buf, size_t count) {
-	ssize_t i=0,x;
+int32_t read_f(int fd, void *buf, size_t count) {
+	int32_t i=0,x;
 
 	while (i!=count) {
 		x=read(fd,(void *) (((char *) buf)+i),count-i);
